@@ -1,9 +1,13 @@
-# Copyright (C) 2012-2019 Etienne Millon <me@emillon.org>
+# Copyright (C) 2012-2021 Etienne Millon <me@emillon.org>
 #                         Gregory Soutade <gregory@soutade.fr>
 #                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
+#                         Karthikeyan Singaravelan <tir.karthi@gmail.com>
+#                         Léo Gaspard <leo@gaspard.io>
 #                         Martin Monperrus <monperrus@users.noreply.github.com>
+#                         Nicolas KAROLAK <nicolas@karolak.fr>
 #                         Profpatsch <mail@profpatsch.de>
 #                         W. Trevor King <wking@tremily.us>
+#                         auouymous <5005204+auouymous@users.noreply.github.com>
 #
 # This file is part of rss2email.
 #
@@ -84,7 +88,7 @@ def run(feeds, args):
                             interval = interval
                         ))
                         _time.sleep(interval)
-                    feed.run(send=args.send)
+                    feed.run(send=args.send, clean=args.clean)
                 except _error.RSS2EmailError as e:
                     e.log()
                 last_server = current_server
@@ -158,7 +162,7 @@ def opmlimport(feeds, args):
         raise _error.OPMLReadError() from e
     if args.file:
         f.close()
-    name_slug_regexp = _re.compile('[^\w\d.-]+')
+    name_slug_regexp = _re.compile(r'[^\w\d.-]+')
     for feed in new_feeds:
         if feed.hasAttribute('xmlUrl'):
             url = _saxutils.unescape(feed.getAttribute('xmlUrl'))
@@ -175,17 +179,17 @@ def opmlexport(feeds, args):
     "Export configuration to OPML."
     if args.file:
         _LOG.info('exporting feeds to {}'.format(args.file))
-        f = open(args.file, 'rb')
+        f = open(args.file, 'wb')
     else:
         _LOG.info('exporting feeds to stdout')
-        f = _sys.stdout
+        f = _sys.stdout.buffer
     f.write(
-        '<?xml version="1.0" encoding="UTF-8"?>\n'
-        '<opml version="1.0">\n'
-        '<head>\n'
-        '<title>rss2email OPML export</title>\n'
-        '</head>\n'
-        '<body>\n')
+        b'<?xml version="1.0" encoding="UTF-8"?>\n'
+        b'<opml version="1.0">\n'
+        b'<head>\n'
+        b'<title>rss2email OPML export</title>\n'
+        b'</head>\n'
+        b'<body>\n')
     for feed in feeds:
         if not feed.url:
             _LOG.debug('dropping {}'.format(feed))
@@ -193,9 +197,9 @@ def opmlexport(feeds, args):
         name = _saxutils.escape(feed.name)
         url = _saxutils.escape(feed.url)
         f.write('<outline type="rss" text="{}" xmlUrl="{}"/>\n'.format(
-                name, url))
+                name, url).encode())
     f.write(
-        '</body>\n'
-        '</opml>\n')
+        b'</body>\n'
+        b'</opml>\n')
     if args.file:
         f.close()
