@@ -1,6 +1,8 @@
-# Copyright (C) 2004-2019 Aaron Swartz
+# Copyright (C) 2004-2021 Aaron Swartz
+#                         Alyssa Ross <hi@alyssa.is>
 #                         Anders Damsgaard <anders@adamsgaard.dk>
 #                         Andrey Zelenchuk <azelenchuk@parallels.com>
+#                         Andrey Zelenchuk <azelenchuk@plesk.com>
 #                         Brian Lalor
 #                         Dean Jackson
 #                         Dmitry Bogatov <KAction@gnu.org>
@@ -12,6 +14,7 @@
 #                         Joey Hess
 #                         Kaashif Hymabaccus <kaashif@kaashif.co.uk>
 #                         Lindsey Smith <lindsey.smith@gmail.com>
+#                         Léo Gaspard <leo@gaspard.io>
 #                         Marcel Ackermann
 #                         Martin 'Joey' Schulze
 #                         Martin Monperrus <monperrus@users.noreply.github.com>
@@ -21,6 +24,10 @@
 #                         Thibaut Girka <thib@sitedethib.com>
 #                         W. Trevor King <wking@tremily.us>
 #                         Yannik Sembritzki <yannik@sembritzki.me>
+#                         auouymous <5005204+auouymous@users.noreply.github.com>
+#                         auouymous <au@qzx.com>
+#                         boyska <piuttosto@logorroici.org>
+#                         ryneeverett <ryneeverett@gmail.com>
 #
 # This file is part of rss2email.
 #
@@ -59,11 +66,17 @@ class Config (_configparser.ConfigParser):
         """
         if section not in self:
             section = 'DEFAULT'
-        _html2text.UNICODE_SNOB = self.getboolean(
+        _html2text.config.UNICODE_SNOB = self.getboolean(
             section, 'unicode-snob')
-        _html2text.LINKS_EACH_PARAGRAPH = self.getboolean(
+        _html2text.config.LINKS_EACH_PARAGRAPH = self.getboolean(
             section, 'links-after-each-paragraph')
-        _html2text.BODY_WIDTH = self.getint(section, 'body-width')
+        _html2text.config.INLINE_LINKS = self.getboolean(
+            section, 'inline-links')
+        _html2text.config.WRAP_LINKS = self.getboolean(
+            section, 'wrap-links')
+        # hack to prevent breaking the default in every existing config file
+        body_width = self.getint(section, 'body-width')
+        _html2text.config.BODY_WIDTH = 0 if body_width < 0 else 78 if body_width == 0 else body_width
 
 
 CONFIG = Config()
@@ -78,11 +91,11 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # Transfer-Encoding. For local mailing it is safe and
         # convenient to use 8bit.
         ('use-8bit', str(False)),
-        # True: Only use the 'from' address.
+        # True: Only use the 'from' address. Overrides the use-publisher-email setting.
         # False: Use the email address specified by the feed, when possible.
         ('force-from', str(False)),
-        # True: Use the publisher's email if you can't find the author's.
-        # False: Just use the 'from' email instead.
+        # True: Use author's email if found, or use publisher's email if found, or use the 'from' setting.
+        # False: Use author's email if found, or use the 'from' setting.
         ('use-publisher-email', str(False)),
         # If empty, only use the feed email address rather than
         # friendly name plus email address.  Available attributes may
@@ -127,6 +140,9 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # because the old entries will not be recorded under their new
         # link-based ids.
         ('trust-link', str(False)),
+        # If 'trust-guid' or 'trust-link' is True, this setting allows to receive
+        # a new email message in reply to the previous one when the post changes.
+        ('reply-changes', str(False)),
         # To most correctly encode emails with international
         # characters, we iterate through the list below and use the
         # first character set that works.
@@ -144,6 +160,7 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # True: Send text/html messages when possible.
         # False: Convert HTML to plain text.
         ('html-mail', str(False)),
+        ('multipart-html', str(False)),
         # Optional CSS styling
         ('use-css', str(False)),
         ('css', (
@@ -190,7 +207,12 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         ('unicode-snob', str(False)),
         # Put the links after each paragraph instead of at the end.
         ('links-after-each-paragraph', str(False)),
-        # Wrap long lines at position. 0 for no wrapping.
+        # Use inline, rather than reference, for formatting images and links.
+        ('inline-links', str(True)),
+        # Wrap links according to body width.
+        ('wrap-links', str(True)),
+        # Wrap long lines at position.
+        # Any negative value for no wrapping, 0 for 78 width (compatibility), or any positive width.
         ('body-width', str(0)),
 
         ### Mailing
@@ -199,6 +221,7 @@ CONFIG['DEFAULT'] = _collections.OrderedDict((
         # True: Use SMTP_SERVER to send mail.
         # Sendmail (or compatible) configuration
         ('sendmail', '/usr/sbin/sendmail'),  # Path to sendmail (or compatible)
+        ('sendmail_config', ''),
         # SMTP configuration
         ('smtp-auth', str(False)),      # set to True to use SMTP AUTH
         ('smtp-username', 'username'),  # username for SMTP AUTH
