@@ -818,7 +818,8 @@ class Feed (object):
                     '<body dir="auto">',
                     '<div id="entry">',
                     '<h1 class="header"><a href="{}">{}</a></h1>'.format(
-                        _saxutils.escape(link), _saxutils.escape(subject)),
+                        _saxutils.escape(link) if link else '',
+                        _saxutils.escape(subject)),
                     '<div id="body">',
                     ])
             if content['type'] in ('text/html', 'application/xhtml+xml'):
@@ -826,10 +827,11 @@ class Feed (object):
             else:
                 lines.append(_saxutils.escape(content['value'].strip()))
             lines.append('</div>')
-            lines.extend([
-                    '<div class="footer">'
-                    '<p>URL: <a href="{0}">{0}</a></p>'.format(_saxutils.escape(link)),
-                    ])
+            lines.append('<div class="footer">')
+            if link:
+                lines.append(
+                    '<p>URL: <a href="{0}">{0}</a></p>'.format(
+                        _saxutils.escape(link)))
             for enclosure in getattr(entry, 'enclosures', []):
                 if getattr(enclosure, 'url', None):
                     lines.append(
