@@ -23,6 +23,7 @@ from typing import List
 sys.path.insert(0, _os.path.dirname(__file__))
 from util.execcontext import r2e_path, ExecContext
 from util.tempmaildir import TemporaryMaildir
+from util.tempsendmail import TemporarySendmail
 
 # Directory containing test feed data/configs
 test_dir = str(Path(__file__).absolute().parent.joinpath("data"))
@@ -115,13 +116,13 @@ class TestEmails(unittest.TestCase, metaclass=TestEmailsMeta):
             text = regexp.sub(replacement, text)
         return text
 
-    def run_single_test(self, dirname=None, config_path=None, force=False):
+    def run_single_test(self, dirname=None, config_path=None):
         if dirname is None:
             dirname = _os.path.dirname(config_path)
         if config_path is None:
             _rss2email.LOG.info('testing {}'.format(dirname))
             for config_path in _glob.glob(_os.path.join(dirname, '*.config')):
-                self.run_single_test(dirname=dirname, config_path=config_path, force=force)
+                self.run_single_test(dirname=dirname, config_path=config_path)
             return
         feed_path = _glob.glob(_os.path.join(dirname, 'feed.*'))[0]
 
@@ -130,16 +131,22 @@ class TestEmails(unittest.TestCase, metaclass=TestEmailsMeta):
         config.read_string(self.BASE_CONFIG_STRING)
         read_paths = config.read([config_path])
         feed = _rss2email_feed.Feed(name='test', url=Path(feed_path).as_posix(), config=config)
-        expected_path = config_path.replace('config', 'expected')
-        with open(expected_path, 'r') as f:
-            expected = self.clean_result(f.read())
         feed._send = TestEmails.Send()
         feed.run()
         generated = feed._send.as_string()
-        if force:
-            with open(expected_path, 'w') as f:
-                f.write(generated)
         generated = self.clean_result(generated)
+
+        expected_path = config_path.replace('config', 'expected')
+        if not _os.path.exists(expected_path):
+            if _os.environ.get('FORCE_TESTDATA_CREATION', '') == '1':
+                with open(expected_path, 'w') as f:
+                    f.write(generated)
+                raise ValueError('missing expected test data, now created')
+            else:
+                raise ValueError('missing test; set FORCE_TESTDATA_CREATION=1 to create')
+        else:
+            with open(expected_path, 'r') as f:
+                expected = f.read()
         if generated != expected:
             diff_lines = _difflib.unified_diff(
                 expected.splitlines(), generated.splitlines(),
@@ -313,6 +320,41 @@ class TestSend(unittest.TestCase):
             self.assertEqual(len([msg for msg in msgs if msg["subject"] == "split massive package into modules"]), 1)
             self.assertEqual(len([msg for msg in msgs if msg["subject"] == "Re: new maintainer and mailing list for rss2email"]), 4)
 
+    def _test_sendmail(self, exitcode, shouldlog, verbose='error'):
+        with TemporarySendmail(exitcode) as sendmail:
+            cfg = """\
+            [DEFAULT]
+            to = example@example.com
+            sendmail = {sendmail}
+            sendmail_config = {sendmail_config}
+            verbose = {verbose}
+            """.format(
+                sendmail=sendmail.bin,
+                sendmail_config=sendmail.config,
+                verbose=verbose)
+
+            with ExecContext(cfg) as ctx:
+                self.httpd_queue.put("next")
+                ctx.call(
+                    "add",
+                    'test',
+                    'http://127.0.0.1:{port}/gmane/feed.rss'.format(
+                        port=self.httpd_port))
+                p = ctx.call("run")
+
+        assertion = self.assertIn if shouldlog else self.assertNotIn
+        assertion("Sendmail failing for reasons...", p.stderr)
+
+    def test_sendmail_success(self):
+        self._test_sendmail(exitcode=0, shouldlog=False)
+
+    def test_sendmail_fail(self):
+        self._test_sendmail(exitcode=1, shouldlog=True)
+
+    def test_sendmail_debug(self):
+        self._test_sendmail(exitcode=0, shouldlog=True, verbose='debug')
+
+
 class TestFeedConfig(unittest.TestCase):
     def test_user_agent_substitutions(self):
         "User agent with substitutions done is not written to config"
@@ -364,6 +406,25 @@ class TestFeedConfig(unittest.TestCase):
             for line in lines[feed_cfg_start:]:
                 self.assertFalse("user-agent" in line)
 
+    def test_verbose_setting_debug(self):
+        "Verbose setting set to debug in configuration should be respected"
+        cfg = """[DEFAULT]
+        verbose = debug
+        """
+        with ExecContext(cfg) as ctx:
+            p = ctx.call("run", "--no-send")
+        self.assertIn('[DEBUG]', p.stderr)
+
+    def test_verbose_setting_info(self):
+        "Verbose setting set to info in configuration should be respected"
+        cfg = """[DEFAULT]
+        verbose = info
+        """
+        with ExecContext(cfg) as ctx:
+            p = ctx.call("run", "--no-send")
+        self.assertNotIn('[DEBUG]', p.stderr)
+
+
 class TestOPML(unittest.TestCase):
     def __init__(self, *args, **kwargs):
         super(TestOPML, self).__init__(*args, **kwargs)
@@ -393,15 +454,15 @@ class TestOPML(unittest.TestCase):
 
     def test_opml_export_without_arg(self):
         with ExecContext(self.cfg) as ctx:
-            # This is just a smoke test for now, it'd be better to capture
+            # This is just a smoke test for now, it'd be better to check
             # stdout but this is enough to check for non-regression
             res = ctx.call("opmlexport")
-            self.assertEqual(res, 0)
+            self.assertEqual(res.returncode, 0)
 
             ctx.call("add", self.feed_name, self.feed_url)
 
             res = ctx.call("opmlexport")
-            self.assertEqual(res, 0)
+            self.assertEqual(res.returncode, 0)
 
     def test_opml_import(self):
         with ExecContext(self.cfg) as ctx:
